@@ -1,10 +1,10 @@
-Pa = 7 # Tanalog = 10**-Pa
+Pa = 10 # Tanalog = 10**-Pa
 #Ta = 10**(-Pa)
 
-Nmax = 1e6 # nombre d'échantillons max dans un signal
+Nmax = 1e7 # nombre d'échantillons max dans un signal
 
 liste_xmin_xmax = [0., 1e-4]
-Xe = 10**-Pa
+Xe = 2e-7 # Signaux par défaut compatibles avec sorties sysam
 
 
 
@@ -15,7 +15,7 @@ type_signal = "cosinus"
 liste_an = [0., Vpp/2]
 liste_bn = []
 liste_umin_umax = [-10, 10]
-Pbits = 16
+Pbits = 16 # Les signaux wav sont codés sur 16 bits 
 
 calibre = 10.
 repetition = True
