@@ -13,7 +13,7 @@ import matplotlib.pyplot as plt
 
 sys.path.append(os.path.join(os.path.dirname(os.path.realpath(__file__)), os.pardir))
 
-from base.temps_base import TempsBase
+from base.axe_x_base import AxeXBase
 from signaux.signal_5_wav import Signal5Wav
 from base.voie_base import VoieBase
 from base.trigger_base import TriggerBase
@@ -25,20 +25,20 @@ __all__ = ["SignalSysam"]
 
 
 class Signal6Sysam(Signal5Wav):
-    # def __init__(self, nom_voie, calibre = 10., liste_tmin_tmax = cst.liste_tmin_tmax, Te = cst.Te, nom = ""):
+    # def __init__(self, nom_voie, calibre = 10., liste_xmin_xmax = cst.liste_xmin_xmax, Xe = cst.Xe, nom = ""):
 
-    #     base_de_temps = BaseTemps(liste_tmin_tmax, Te)
-    #     SignalComplet.__init__(self, base_de_temps = base_de_temps, nom = nom)
+    #     axe_x_base = AxeXBase(liste_xmin_xmax, Xe)
+    #     SignalComplet.__init__(self, axe_x_base = axe_x_base, nom = nom)
     #     self.configurer_voie(nom_voie, calibre)
 
-    def lire_voie_base(self):
+    def __lire_voie_base(self):
         try:
             a = self.__voie_base
         except:
             self.__voie_base = VoieBase()
         return self.__voie_base
         
-    def lire_trigger_base(self):
+    def __lire_trigger_base(self):
         try:
             a = self.__trigger_base
         except:
@@ -46,8 +46,8 @@ class Signal6Sysam(Signal5Wav):
         return self.__trigger_base
     
     def __str__(self):
-        trigger_base = self.lire_trigger_base()
-        voie_base = self.lire_voie_base()
+        trigger_base = self.__lire_trigger_base()
+        voie_base = self.__lire_voie_base()
         chaine = self.lire_nom()
         if voie_base.tester():
             chaine += "({0})".format(voie_base.nom)
@@ -55,26 +55,26 @@ class Signal6Sysam(Signal5Wav):
             chaine += "T"
         return chaine
 
-    def configurer_voie(self, nom, calibre = 10., repetition = True):
-        voie_base = self.lire_voie_base()
+    def configurer_voie(self, nom="", calibre = 10., repetition = True):
+        voie_base = self.__lire_voie_base()
         voie_base.nom = nom
         voie_base.calibre = calibre
         voie_base.repetition = repetition
 
     def configurer_trigger(self, seuil, montant = True, pretrigger = 0, pretrigger_souple = False, hysteresys = False):
-        trigger_base = self.lire_trigger_base()
+        trigger_base = self.__lire_trigger_base()
         trigger_base.seuil = seuil
         trigger_base.montant = montant
         trigger_base.pretrigger = pretrigger
         trigger_base.pretrigger_souple = pretrigger_souple
         trigger_base.hysteresys = hysteresys
 
-    def calculer_calibre_optimal(self):
+    def __calculer_calibre_optimal(self):
         liste = base.voie_base.liste_calibres_entrees
         liste.sort()
 
-        signal_max = np.max(self.lire_vecteur_signal())
-        signal_min = np.min(self.lire_vecteur_signal())
+        signal_max = np.max(self.lire_vecteur_y())
+        signal_min = np.min(self.lire_vecteur_y())
         calibre_min = max(np.abs(signal_max), np.abs(signal_min))
         for calibre in liste:
             if calibre > calibre_min:
@@ -108,10 +108,10 @@ class Signal6Sysam(Signal5Wav):
 
 if __name__ == "__main__":
 
-    liste_tmin_tmax=[0, 1e-8]
-    Te = 2e-7
+    liste_xmin_xmax=[0, 1e-8]
+    Xe = 2e-7
 
-    bdt = TempsBase(liste_tmin_tmax, Te)
+    bdt = AxeXBase(liste_xmin_xmax, Xe)
 
     liste_signaux = []
 
@@ -130,3 +130,4 @@ if __name__ == "__main__":
 
     print("fin")
 
+    print(type(s))
