@@ -14,7 +14,7 @@ sys.path.append(os.path.join(os.path.dirname(os.path.realpath(__file__)), os.par
 
 import base.constantes_base as cst
 import base.utiles_base as utb
-from base.temps_base import BaseTemps, convertir_vecteur_t_vers_base_de_temps
+from base.axe_x_base import AxeXBase, convertir_vecteur_x_vers_axe_x_base
 from signaux.signal_complet import SignalComplet
 from base.voie_base import Voie
 from base.trigger_base import Trigger
@@ -28,11 +28,11 @@ __all__ = ["SignalSysam"]
 
 
 class SignalPerso(SignalComplet):
-    def __init__(self, vecteur_t, vecteur_signal = [], nom = ""):
+    def __init__(self, vecteur_x, vecteur_y = [], nom = ""):
 
-        base_de_temps = convertir_vecteur_t_vers_base_de_temps(vecteur_t)
-        print(base_de_temps, base_de_temps.N)
-        SignalComplet.__init__(self, base_de_temps, vecteur_signal, nom)
+        axe_x_base = convertir_vecteur_x_vers_axe_x_base(vecteur_x)
+        print(axe_x_base, axe_x_base.N)
+        SignalComplet.__init__(self, axe_x_base, vecteur_y, nom)
 
     # def configurer_sysam(self, nom_voie, calibre = 10., repetition = False):
     #     self.voie.nom = nom_voie
@@ -55,11 +55,11 @@ class SignalPerso(SignalComplet):
 
 if __name__ == "__main__":
 
-    vecteur_t = np.linspace(0,10,1000)
-    s1 = SignalPerso(vecteur_t)
-    vecteur_t_bis = s1.base_de_temps.calculer_vecteur_t()
-    # print(vecteur_t)
-    # print(vecteur_t_bis)
+    vecteur_x = np.linspace(0,10,1000)
+    s1 = SignalPerso(vecteur_x)
+    vecteur_x_bis = s1.axe_x_base.lire_vecteur_x()
+    # print(vecteur_x)
+    # print(vecteur_x_bis)
     s1.tracer_signal()
     print("fin")
 
