@@ -53,6 +53,12 @@ def demarrer_sysam(*args, **kwargs):
 #                 os._sys.exit(0)
 
 class SysamSP5(Sysam4Methodes):
+    def raz_sorties(self):
+        print("raz_sorties")
+        self.sysam.config_sortie(1, 1, np.zeros(10), 0)
+        self.sysam.config_sortie(2, 1, np.zeros(10), 0)
+        self.sysam.declencher_sorties(1, 1)
+
     def __init__(self, liste_signaux, affichage = True):
         Sysam4Methodes.__init__(self, liste_signaux, affichage)
 
@@ -91,6 +97,7 @@ class SysamSP5(Sysam4Methodes):
                 chaine = input("On arrête les signaux o/N?")
                 if chaine == "o" or chaine == "O":
                     test_fin = True
+        # self.raz_sorties()
 
     def mettre_a_jour_entrees(self):
         # print("On met les entrées à jour")
@@ -120,5 +127,5 @@ if __name__ == "__main__":
     # s4 = Signal(liste_tmin_tmax =liste_tmin_tmax, nom_voie = "SA2", Te = Te)
     s5 = Signal(F = 1e4, liste_tmin_tmax =liste_tmin_tmax, nom_voie = "SA1", Te = Te)
     
-    demarrer_sysam(s1, s5, True)
-    tracer(s1, s5, superposition = False)
\ No newline at end of file
+    demarrer_sysam(s5, True)
+    # tracer(s1, s5, superposition = False)
\ No newline at end of file
